@@ -44,8 +44,8 @@ def main():
                             correct = of.read().strip()
                             if str(out) != str(correct):
                                 print("Wrong Answer on", i)
-                                print("Output:", out)
-                                print("\nExpected:", correct)
+                                print("Output:\n" + str(out), file=open("tf.txt", "w"))
+                                print("Expected:\n" + str(correct), file=open("tf.txt", "w"))
                                 wa = True
                                 break
                         else:
